#!/usr/bin/env python3

"""Delete Docker Deployment from MeX via API

This script will allow the user to delete a previously created docker
deployment using the MeX API.

This is a POC only, and is not intended for production use:
  - All variables are hardcoded into this script.
  - Credentials are stored in this script.
  - No error handling is present in this code.
  - The script is devoid of functions and is pretty stupid.

The script assumes you have created a deployment using the create
docker deployment script. It also assumes that you have
credentials for that account and that they are added into
this file.

JAS 9-APR-2020
"""


import simplejson as json
import requests


## MEX Variables
ACCPORTS = "TCP:8000"
ACCTYPE = 0
ALLIP = "dynamic"
APPNAME = "testapp"
APPVER = "1.1"
CLDLET = "munich-main"
CLSTR = "testcluster"
FLAVOR = "m4.small"
IMGPATH = "docker.mobiledgex.net/demoorg/images/test:1.1"
IMGTYPE = 1
INTPORTS = True
IPACC = 1
MEXPASS = "helloworld"
MEXUSER = "demo"
OPKEY = "TDG"
ORG = "demoorg"
REGION = "EU"
REV = 0
TYPE = "docker"

## Call Variables
HEADERS = {'Content-Type': 'application/json'}

########################################################
## Login

# Endpoint / Route
url = "https://console.mobiledgex.net/api/v1/login"

# Payload
payload = {
  "username": MEXUSER,
  "password": MEXPASS
}

payload_json = json.dumps(payload)  # Convert dict to json string

# Call the API and parse out the token
response = requests.post(url, data=payload_json, headers=HEADERS)
parsed = json.loads(response.text)
thetoken = (parsed['token'])

# Build our header
bt = "Bearer " + thetoken

# Add to our headers
HEADERS['Authorization'] = bt


########################################################
# Delete AppInst Section

print("Deleting the AppInst...")

# Endpoint / Route
url = "https://console.mobiledgex.net/api/v1/auth/ctrl/DeleteAppInst"

# Payload
payload = {
  "Region": REGION,
  "AppInst": {
    "key": {
      "app_key": {
        "organization": ORG,
        "name": APPNAME,
        "version": APPVER,
        "developer_key": {
          "name": ORG
        }
      },
      "cluster_inst_key": {
        "cluster_key": {
          "name": CLSTR
        },
        "cloudlet_key": {
          "operator_key": {
            "name": OPKEY
          },
          "name": CLDLET
        },
        "developer": ORG
      }
    },
    "flavor": {
      "name": FLAVOR
    }
  }
}


# Convert dict to json string
payload_json = json.dumps(payload)

# Call the API
response = requests.post(url, data=payload_json, headers=HEADERS)

# Print the response
print(response.text)


########################################################
## Delete Cluster Section
print("Deleting the cluster...")

# Endpoint / Route
url = "https://console.mobiledgex.net/api/v1/auth/ctrl/DeleteClusterInst"


# Payload
payload = {
  "Region": REGION,
  "ClusterInst": {
    "allocated_ip": ALLIP,
    "ip_access": IPACC,
    "key": {
      "cloudlet_key": {
        "operator_key": {
          "name": OPKEY
        },
        "name": CLDLET
      },
      "developer": ORG,
      "developer_key": {
        "name": ORG
      },
      "cluster_key": {
        "name": CLSTR
      },
      "organization": ORG
    },
    "deployment": TYPE,
    "node_flavor": FLAVOR,
    "flavor": {
      "name": FLAVOR
    },

  }
}


# Convert dict to json string
payload_json = json.dumps(payload)

# Call the API
response = requests.post(url, data=payload_json, headers=HEADERS)

# Print the response
print(response.text)


########################################################
## Delete App Section

print("Deleting the application...")

# Endpoint / Route
url = "https://console.mobiledgex.net/api/v1/auth/ctrl/DeleteApp"


# Payload
payload = {
"Region": REGION,
"App": {
  "key": {
    "developer_key" : {
      "name": ORG
    },
    "name": APPNAME,
    "organization": ORG,
    "version": APPVER
  },
  "deployment": TYPE,
  "access_type": ACCTYPE,
  "image_path": IMGPATH,
  "image_type": IMGTYPE,
  "internal_ports": INTPORTS,
  "default_flavor": {
    "name": FLAVOR,
  },
  "revision": REV,
  "access_ports": ACCPORTS
}
}


# Convert dict to json string
payload_json = json.dumps(payload)

# Call the API
response = requests.post(url, data=payload_json, headers=HEADERS)

# Print the response
print(response.text)



